@@ -12,12 +12,19 @@ class Metric(BaseModel):
     aggregation_type: str
 
 
+class PricingUnitDetails(BaseModel):
+    amount_cents: int
+    short_name: str
+    conversion_rate: float
+
+
 class ChargeFilterUsage(BaseModel):
     invoice_display_name: Optional[str]
     values: Dict[str, List[str]]
     units: str
     amount_cents: int
     events_count: int
+    pricing_unit_details: Optional[PricingUnitDetails]
 
 
 class ChargeObject(BaseModel):
@@ -29,13 +36,14 @@ class ChargeObject(BaseModel):
 class GroupedUsage(BaseModel):
     amount_cents: int
     events_count: int
-    units: float
+    units: str
     grouped_by: Dict[str, str]
     filters: List[ChargeFilterUsage]
+    pricing_unit_details: Optional[PricingUnitDetails]
 
 
 class ChargeUsage(BaseModel):
-    units: float
+    units: str
     events_count: int
     amount_cents: int
     amount_currency: str
@@ -43,6 +51,7 @@ class ChargeUsage(BaseModel):
     billable_metric: Metric
     filters: List[ChargeFilterUsage]
     grouped_usage: Optional[List[GroupedUsage]]
+    pricing_unit_details: Optional[PricingUnitDetails]
 
 
 class CustomerUsageResponse(BaseResponseModel):
